@@ -52,6 +52,9 @@ extern struct usbg_function_type usbg_f_type_phonet;
 extern struct usbg_function_type usbg_f_type_loopback;
 extern struct usbg_function_type usbg_f_type_hid;
 extern struct usbg_function_type usbg_f_type_uac2;
+extern struct usbg_function_type usbg_f_type_uvc;
+extern struct usbg_function_type usbg_f_type_printer;
+extern struct usbg_function_type usbg_f_type_9pfs;
 
 /**
  * @var function_types
@@ -73,9 +76,12 @@ struct usbg_function_type* function_types[] = {
 	[USBG_F_LOOPBACK] = &usbg_f_type_loopback,
 	[USBG_F_HID] = &usbg_f_type_hid,
 	[USBG_F_UAC2] = &usbg_f_type_uac2,
+	[USBG_F_UVC] = &usbg_f_type_uvc,
+	[USBG_F_PRINTER] = &usbg_f_type_printer,
+	[USBG_F_9PFS] = &usbg_f_type_9pfs,
 };
 
-ARRAY_SIZE_SENTINEL(function_types, USBG_FUNCTION_TYPE_MAX);
+ARRAY_SIZE_SENTINEL(function_types, USBG_FUNCTION_TYPE_MAX)
 
 const char *gadget_attr_names[] =
 {
@@ -89,7 +95,7 @@ const char *gadget_attr_names[] =
 	"bcdDevice"
 };
 
-ARRAY_SIZE_SENTINEL(gadget_attr_names, USBG_GADGET_ATTR_MAX);
+ARRAY_SIZE_SENTINEL(gadget_attr_names, USBG_GADGET_ATTR_MAX)
 
 const char *gadget_str_names[] =
 {
@@ -98,7 +104,7 @@ const char *gadget_str_names[] =
 	"serialnumber",
 };
 
-ARRAY_SIZE_SENTINEL(gadget_str_names, USBG_GADGET_STR_MAX);
+ARRAY_SIZE_SENTINEL(gadget_str_names, USBG_GADGET_STR_MAX)
 
 const char *gadget_os_desc_names[] =
 {
@@ -107,7 +113,7 @@ const char *gadget_os_desc_names[] =
 	"qw_sign",
 };
 
-ARRAY_SIZE_SENTINEL(gadget_os_desc_names, USBG_GADGET_OS_DESC_MAX);
+ARRAY_SIZE_SENTINEL(gadget_os_desc_names, USBG_GADGET_OS_DESC_MAX)
 
 int usbg_lookup_function_type(const char *name)
 {
@@ -747,8 +753,7 @@ static int usbg_parse_config(const char *path, const char *name,
 		goto free_config;
 
 	TAILQ_INSERT_TAIL(&g->configs, c, cnode);
-
-	return USBG_SUCCESS;
+	goto out;
 
 free_config:
 	usbg_free_config(c);
